@@ -1,31 +1,48 @@
+
 simulglyph.vmf <-
-function(s2grid=NULL, angles=c(20,100), depth=3, b=3000, mddratio=1.24, sigma=NULL, threshold=0.4, snapshot=FALSE, savedir=tempdir(), pngfig="glyph1", showglyph=TRUE)
+function(gdi="gqi", s2grid=NULL, angles=c(20,100), depth=3, b=3000, lambda=NULL, order=4, sigma=NULL, threshold=0.4, snapshot=FALSE, savedir=tempdir(), pngfig="glyph1", showglyph=TRUE, aniso=NULL, logplot=TRUE, wi=c(0.5,0.5))
 {
+  gdimethods <- c("gqi", "gqi2", "sph")
+  gdimethod <- match(gdi, gdimethods)
+  stopifnot(is.na(gdimethod) != TRUE)
   if(is.null(s2grid)) {
     ## S2 grid
     s2 <- s2tessel.zorder(depth=depth)
     g0 <- s2$pc
   }
-	else 
+  else 
     g0 <- s2grid
   ## synthetize diffusion signal
   ## open3d()
-  S <- synthfiberss2z(g0=g0, angles=angles, logplot=TRUE, b=b, S0=1,
-    sigma=sigma, showglyph=showglyph)
+  S <- synthfiberss2z(g0=g0, angles=angles, logplot=logplot, b=b, S0=1,
+    sigma=sigma, showglyph=showglyph, wi=wi)
   if(snapshot) {
     ## sp <- tempfile(pattern="gsim", tmpdir=savedir, fileext=".png")
     sp <- paste(savedir,"/",pngfig,"a.png", sep="")
     rgl.bringtotop();  rgl.snapshot(sp)
     cat("snapshot file", sp,"\n")
   }
-  ##
+  ##-------------------
   ## ODF reconstruction 
-  br <- rep(b, length(S))
-  btable <- cbind(br, g0)
   # cat("Estimating slice odfs ...\n")
-  q2odf <- gqifn(odfvert=g0, btable=btable, mddratio=mddratio)
-  odf <- q2odf%*%S
-  odf <- odf - min(odf)
+  switch(gdimethod,
+    { br <- rep(b, length(S))
+      btable <- cbind(br, g0)
+      q2odf <- gqifn(odfvert=g0, btable=btable, lambda=lambda)
+      odf <- q2odf%*%S }, # GQI
+    { br <- rep(b, length(S)) 
+      btable <- cbind(br, g0)
+      q2odf <- gqifn2(odfvert=g0, btable=btable, lambda=lambda)
+      odf <- q2odf%*%S }, # GQI@
+    {  odf <- sphodf(g0=g0, S=S, order=order, lambda=lambda) } # SPH.w
+  )
+  ##--------------------
+  if(!is.null(aniso)) {
+    stopifnot(aniso >= 0 & aniso < 1)
+    mx <- max(odf)  
+    mn <- min(odf)  
+    odf <- pmax(odf-mn-aniso*(mx-mn),0)
+  }
   odf <- (odf - min(odf))/diff(range(odf)) 
   ## vmf maxima estimation
   a <- gdi.vmf(odf=odf, odfvertices=g0, threshold=threshold,
@@ -39,6 +56,39 @@ function(s2grid=NULL, angles=c(20,100), depth=3, b=3000, mddratio=1.24, sigma=NU
   invisible(a)
 }
 
+sphodf <-
+function(g0, S, order=4, lambda=0.006) 
+{
+  ## SPH process preparation
+  cat("Estimating slice odfs ...\n")
+  # gradient <- t(odfvertices)
+  gradient <- t(g0)
+  ## SPH: get SH design matrix ...
+
+  z <- design.spheven(order,gradient,lambda=lambda) # OK
+  # z <- design.wspheven(order,gradient,lambda=lambda) ## blobbier!!
+
+  plz <- plzero(order)/2/pi
+  ngrad <- dim(gradient)[2]
+  ngrad0 <- ngrad
+  lord <- rep(seq(0,order,2),2*seq(0,order,2)+1)
+  while(length(lord)>=ngrad0){
+     order <- order-2
+     lord <- rep(seq(0,order,2),2*seq(0,order,2)+1)
+     cat("Reduced order of spherical harmonics to",order,"\n")
+  }
+  cat("Using",length(lord),"sperical harmonics\n")
+  L <- -diag(lord*(lord+1))
+  ## SPH process 
+  sicoef <- z$matrix%*% S
+  sphcoef <- plz%*%L%*%sicoef
+  coef0 <- sphcoef[1,]
+  sphcoef[1,] <- 1/2/sqrt(pi)
+  sphcoef[-1,] <- sphcoef[-1,]/8/pi
+  sphcoef <- plzero(order)%*%sicoef
+  odf <- t(z$design) %*% sphcoef#####
+  invisible(odf)
+}
 
 gdi.vmf <- 
 function(odf, odfvertices, threshold=0.5, showglyph=TRUE)
